Anomaly class

An unusual cost pattern. This consists of the detailed metadata and the current status of the anomaly object.

Constructors

Anomaly({required String anomalyId, required AnomalyScore anomalyScore, required Impact impact, required String monitorArn, String? anomalyEndDate, String? anomalyStartDate, String? dimensionValue, AnomalyFeedbackType? feedback, List<RootCause>? rootCauses})
Anomaly.fromJson(Map<String, dynamic> json)
factory

Properties

anomalyEndDate → String?
The last day the anomaly is detected.
final
anomalyId → String
The unique identifier for the anomaly.
final
anomalyScore → AnomalyScore
The latest and maximum score for the anomaly.
final
anomalyStartDate → String?
The first day the anomaly is detected.
final
dimensionValue → String?
The dimension for the anomaly. For example, an AWS service in a service monitor.
final
feedback → AnomalyFeedbackType?
The feedback value.
final
hashCode → int
The hash code for this object.
no setterinherited
impact → Impact
The dollar impact for the anomaly.
final
monitorArn → String
The Amazon Resource Name (ARN) for the cost monitor that generated this anomaly.
final
rootCauses → List<RootCause>?
The list of identified root causes for the anomaly.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited