AnomalyScore class

Quantifies the anomaly. The higher score means that it is more anomalous.

Constructors

AnomalyScore({required double currentScore, required double maxScore})
AnomalyScore.fromJson(Map<String, dynamic> json)
factory

Properties

currentScore → double
The last observed score.
final
hashCode → int
The hash code for this object.
no setterinherited
maxScore → double
The maximum score observed during the AnomalyDateInterval.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited