AnomalySubscription class

The association between a monitor, threshold, and list of subscribers used to deliver notifications about anomalies detected by a monitor that exceeds a threshold. The content consists of the detailed metadata and the current status of the AnomalySubscription object.

Constructors

AnomalySubscription({required AnomalySubscriptionFrequency frequency, required List<String> monitorArnList, required List<Subscriber> subscribers, required String subscriptionName, required double threshold, String? accountId, String? subscriptionArn})
AnomalySubscription.fromJson(Map<String, dynamic> json)
factory

Properties

accountId → String?
Your unique account identifier.
final
frequency → AnomalySubscriptionFrequency
The frequency at which anomaly reports are sent over email.
final
hashCode → int
The hash code for this object.
no setterinherited
monitorArnList → List<String>
A list of cost anomaly monitors.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscribers → List<Subscriber>
A list of subscribers to notify.
final
subscriptionArn → String?
The AnomalySubscription Amazon Resource Name (ARN).
final
subscriptionName → String
The name for the subscription.
final
threshold → double
The dollar value that triggers a notification if the threshold is exceeded.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited