Coverage class

The amount of instance usage that a reservation covered.

Constructors

Coverage({CoverageCost? coverageCost, CoverageHours? coverageHours, CoverageNormalizedUnits? coverageNormalizedUnits})
Coverage.fromJson(Map<String, dynamic> json)
factory

Properties

coverageCost → CoverageCost?
The amount of cost that the reservation covered.
final
coverageHours → CoverageHours?
The amount of instance usage that the reservation covered, in hours.
final
coverageNormalizedUnits → CoverageNormalizedUnits?
The amount of instance usage that the reservation covered, in normalized units.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited