CoverageByTime class

Reservation coverage for a specified period, in hours.

Constructors

CoverageByTime({List<ReservationCoverageGroup>? groups, DateInterval? timePeriod, Coverage? total})
CoverageByTime.fromJson(Map<String, dynamic> json)
factory

Properties

groups → List<ReservationCoverageGroup>?
The groups of instances that the reservation covered.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timePeriod → DateInterval?
The period that this coverage was used over.
final
total → Coverage?
The total reservation coverage, in hours.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited