CurrentInstance class

Context about the current instance.

Constructors

CurrentInstance({String? currencyCode, String? instanceName, String? monthlyCost, String? onDemandHoursInLookbackPeriod, String? reservationCoveredHoursInLookbackPeriod, ResourceDetails? resourceDetails, String? resourceId, ResourceUtilization? resourceUtilization, String? savingsPlansCoveredHoursInLookbackPeriod, List<TagValues>? tags, String? totalRunningHoursInLookbackPeriod})
CurrentInstance.fromJson(Map<String, dynamic> json)
factory

Properties

currencyCode → String?
The currency code that AWS used to calculate the costs for this instance.
final
hashCode → int
The hash code for this object.
no setterinherited
instanceName → String?
The name you've given an instance. This field will show as blank if you haven't given the instance a name.
final
monthlyCost → String?
Current On-Demand cost of operating this instance on a monthly basis.
final
onDemandHoursInLookbackPeriod → String?
Number of hours during the lookback period billed at On-Demand rates.
final
reservationCoveredHoursInLookbackPeriod → String?
Number of hours during the lookback period covered by reservations.
final
resourceDetails → ResourceDetails?
Details about the resource and utilization.
final
resourceId → String?
Resource ID of the current instance.
final
resourceUtilization → ResourceUtilization?
Utilization information of the current instance during the lookback period.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
savingsPlansCoveredHoursInLookbackPeriod → String?
Number of hours during the lookback period covered by Savings Plans.
final
tags → List<TagValues>?
Cost allocation resource tags applied to the instance.
final
totalRunningHoursInLookbackPeriod → String?
The total number of hours the instance ran during the lookback period.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited