DimensionValues class

The metadata that you can use to filter and group your results. You can use GetDimensionValues to find specific values.

Constructors

DimensionValues({Dimension? key, List<MatchOption>? matchOptions, List<String>? values})
DimensionValues.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → Dimension?
The names of the metadata types that you can use to filter and group your results. For example, AZ returns a list of Availability Zones.
final
matchOptions → List<MatchOption>?
The match options that you can use to filter your results. MatchOptions is only applicable for actions related to Cost Category. The default values for MatchOptions are EQUALS and CASE_SENSITIVE.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values → List<String>?
The metadata values that you can use to filter and group your results. You can use GetDimensionValues to find specific values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited