EBSResourceUtilization class

The EBS field that contains a list of EBS metrics associated with the current instance.

Constructors

EBSResourceUtilization({String? ebsReadBytesPerSecond, String? ebsReadOpsPerSecond, String? ebsWriteBytesPerSecond, String? ebsWriteOpsPerSecond})
EBSResourceUtilization.fromJson(Map<String, dynamic> json)
factory

Properties

ebsReadBytesPerSecond → String?
The maximum size of read operations per second
final
ebsReadOpsPerSecond → String?
The maximum number of read operations per second.
final
ebsWriteBytesPerSecond → String?
The maximum size of write operations per second.
final
ebsWriteOpsPerSecond → String?
The maximum number of write operations per second.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited