EC2ResourceDetails class

Details on the Amazon EC2 Resource.

Constructors

EC2ResourceDetails({String? hourlyOnDemandRate, String? instanceType, String? memory, String? networkPerformance, String? platform, String? region, String? sku, String? storage, String? vcpu})
EC2ResourceDetails.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
hourlyOnDemandRate → String?
Hourly public On-Demand rate for the instance type.
final
instanceType → String?
The type of AWS instance.
final
memory → String?
Memory capacity of the AWS instance.
final
networkPerformance → String?
Network performance capacity of the AWS instance.
final
platform → String?
The platform of the AWS instance. The platform is the specific combination of operating system, license model, and software on an instance.
final
region → String?
The AWS Region of the instance.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sku → String?
The SKU of the product.
final
storage → String?
The disk storage of the AWS instance (not EBS storage).
final
vcpu → String?
Number of VCPU cores in the AWS instance type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited