EC2ResourceUtilization class

Utilization metrics of the instance.

Constructors

EC2ResourceUtilization({EBSResourceUtilization? eBSResourceUtilization, String? maxCpuUtilizationPercentage, String? maxMemoryUtilizationPercentage, String? maxStorageUtilizationPercentage})
EC2ResourceUtilization.fromJson(Map<String, dynamic> json)
factory

Properties

eBSResourceUtilization → EBSResourceUtilization?
The EBS field that contains a list of EBS metrics associated with the current instance.
final
hashCode → int
The hash code for this object.
no setterinherited
maxCpuUtilizationPercentage → String?
Maximum observed or expected CPU utilization of the instance.
final
maxMemoryUtilizationPercentage → String?
Maximum observed or expected memory utilization of the instance.
final
maxStorageUtilizationPercentage → String?
Maximum observed or expected storage utilization of the instance (does not measure EBS storage).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited