GetAnomalySubscriptionsResponse class

Constructors

GetAnomalySubscriptionsResponse({required List<AnomalySubscription> anomalySubscriptions, String? nextPageToken})
GetAnomalySubscriptionsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

anomalySubscriptions → List<AnomalySubscription>
A list of cost anomaly subscriptions that includes the detailed metadata for each one.
final
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken → String?
The token to retrieve the next set of results. AWS provides the token when the response from a previous call has more results than the maximum page size.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited