GetDimensionValuesResponse class

Constructors

GetDimensionValuesResponse({required List<DimensionValuesWithAttributes> dimensionValues, required int returnSize, required int totalSize, String? nextPageToken})
GetDimensionValuesResponse.fromJson(Map<String, dynamic> json)
factory

Properties

dimensionValues → List<DimensionValuesWithAttributes>
The filters that you used to filter your request. Some dimensions are available only for a specific context.
final
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken → String?
The token for the next set of retrievable results. AWS provides the token when the response from a previous call has more results than the maximum page size.
final
returnSize → int
The number of results that AWS returned at one time.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalSize → int
The total number of search results.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited