GetReservationCoverageResponse class

Constructors

GetReservationCoverageResponse({required List<CoverageByTime> coveragesByTime, String? nextPageToken, Coverage? total})
GetReservationCoverageResponse.fromJson(Map<String, dynamic> json)
factory

Properties

coveragesByTime → List<CoverageByTime>
The amount of time that your reservations covered.
final
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken → String?
The token for the next set of retrievable results. AWS provides the token when the response from a previous call has more results than the maximum page size.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
total → Coverage?
The total amount of instance usage that a reservation covered.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited