GroupDefinition class

Represents a group when you specify a group by criteria or in the response to a query with a specific grouping.

Constructors

GroupDefinition({String? key, GroupDefinitionType? type})
GroupDefinition.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → String?
The string that represents a key for a specified group.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → GroupDefinitionType?
The string that represents the type of group.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited