InstanceDetails class

Details about the instances that AWS recommends that you purchase.

Constructors

InstanceDetails({EC2InstanceDetails? eC2InstanceDetails, ESInstanceDetails? eSInstanceDetails, ElastiCacheInstanceDetails? elastiCacheInstanceDetails, RDSInstanceDetails? rDSInstanceDetails, RedshiftInstanceDetails? redshiftInstanceDetails})
InstanceDetails.fromJson(Map<String, dynamic> json)
factory

Properties

eC2InstanceDetails → EC2InstanceDetails?
The Amazon EC2 instances that AWS recommends that you purchase.
final
elastiCacheInstanceDetails → ElastiCacheInstanceDetails?
The ElastiCache instances that AWS recommends that you purchase.
final
eSInstanceDetails → ESInstanceDetails?
The Amazon ES instances that AWS recommends that you purchase.
final
hashCode → int
The hash code for this object.
no setterinherited
rDSInstanceDetails → RDSInstanceDetails?
The Amazon RDS instances that AWS recommends that you purchase.
final
redshiftInstanceDetails → RedshiftInstanceDetails?
The Amazon Redshift instances that AWS recommends that you purchase.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited