MetricValue class

The aggregated value for a metric.

Constructors

MetricValue({String? amount, String? unit})
MetricValue.fromJson(Map<String, dynamic> json)
factory

Properties

amount → String?
The actual number that represents the metric.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unit → String?
The unit that the metric is given in.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited