RedshiftInstanceDetails class

Details about the Amazon Redshift instances that AWS recommends that you purchase.

Constructors

RedshiftInstanceDetails({bool? currentGeneration, String? family, String? nodeType, String? region, bool? sizeFlexEligible})
RedshiftInstanceDetails.fromJson(Map<String, dynamic> json)
factory

Properties

currentGeneration → bool?
Whether the recommendation is for a current-generation instance.
final
family → String?
The instance family of the recommended reservation.
final
hashCode → int
The hash code for this object.
no setterinherited
nodeType → String?
The type of node that AWS recommends.
final
region → String?
The AWS Region of the recommended reservation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeFlexEligible → bool?
Whether the recommended reservation is size flexible.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited