ReservationAggregates class

The aggregated numbers for your reservation usage.

Constructors

ReservationAggregates({String? amortizedRecurringFee, String? amortizedUpfrontFee, String? netRISavings, String? onDemandCostOfRIHoursUsed, String? purchasedHours, String? purchasedUnits, String? totalActualHours, String? totalActualUnits, String? totalAmortizedFee, String? totalPotentialRISavings, String? unusedHours, String? unusedUnits, String? utilizationPercentage, String? utilizationPercentageInUnits})
ReservationAggregates.fromJson(Map<String, dynamic> json)
factory

Properties

amortizedRecurringFee → String?
The monthly cost of your reservation, amortized over the reservation period.
final
amortizedUpfrontFee → String?
The upfront cost of your reservation, amortized over the reservation period.
final
hashCode → int
The hash code for this object.
no setterinherited
netRISavings → String?
How much you saved due to purchasing and utilizing reservation. AWS calculates this by subtracting TotalAmortizedFee from OnDemandCostOfRIHoursUsed.
final
onDemandCostOfRIHoursUsed → String?
How much your reservation would cost if charged On-Demand rates.
final
purchasedHours → String?
How many reservation hours that you purchased.
final
purchasedUnits → String?
How many Amazon EC2 reservation hours that you purchased, converted to normalized units. Normalized units are available only for Amazon EC2 usage after November 11, 2017.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalActualHours → String?
The total number of reservation hours that you used.
final
totalActualUnits → String?
The total number of Amazon EC2 reservation hours that you used, converted to normalized units. Normalized units are available only for Amazon EC2 usage after November 11, 2017.
final
totalAmortizedFee → String?
The total cost of your reservation, amortized over the reservation period.
final
totalPotentialRISavings → String?
How much you could save if you use your entire reservation.
final
unusedHours → String?
The number of reservation hours that you didn't use.
final
unusedUnits → String?
The number of Amazon EC2 reservation hours that you didn't use, converted to normalized units. Normalized units are available only for Amazon EC2 usage after November 11, 2017.
final
utilizationPercentage → String?
The percentage of reservation time that you used.
final
utilizationPercentageInUnits → String?
The percentage of Amazon EC2 reservation time that you used, converted to normalized units. Normalized units are available only for Amazon EC2 usage after November 11, 2017.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited