ReservationUtilizationGroup class

A group of reservations that share a set of attributes.

Constructors

ReservationUtilizationGroup({Map<String, String>? attributes, String? key, ReservationAggregates? utilization, String? value})
ReservationUtilizationGroup.fromJson(Map<String, dynamic> json)
factory

Properties

attributes → Map<String, String>?
The attributes for this group of reservations.
final
hashCode → int
The hash code for this object.
no setterinherited
key → String?
The key for a specific reservation attribute.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
utilization → ReservationAggregates?
How much you used this group of reservations.
final
value → String?
The value of a specific reservation attribute.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited