RightsizingRecommendationMetadata class

Metadata for this recommendation set.

Constructors

RightsizingRecommendationMetadata({String? additionalMetadata, String? generationTimestamp, LookbackPeriodInDays? lookbackPeriodInDays, String? recommendationId})
RightsizingRecommendationMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

additionalMetadata → String?
Additional metadata that may be applicable to the recommendation.
final
generationTimestamp → String?
The timestamp for when AWS made this recommendation.
final
hashCode → int
The hash code for this object.
no setterinherited
lookbackPeriodInDays → LookbackPeriodInDays?
How many days of previous usage that AWS considers when making this recommendation.
final
recommendationId → String?
The ID for this specific recommendation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited