RootCause class

The combination of AWS service, linked account, Region, and usage type where a cost anomaly is observed.

Constructors

RootCause({String? linkedAccount, String? region, String? service, String? usageType})
RootCause.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
linkedAccount → String?
The linked account value associated with the cost anomaly.
final
region → String?
The AWS Region associated with the cost anomaly.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service → String?
The AWS service name associated with the cost anomaly.
final
usageType → String?
The UsageType value associated with the cost anomaly.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited