SavingsPlansPurchaseRecommendation class
Contains your request parameters, Savings Plan Recommendations Summary, and Details.
Constructors
-
SavingsPlansPurchaseRecommendation({AccountScope? accountScope, LookbackPeriodInDays? lookbackPeriodInDays, PaymentOption? paymentOption, List<
SavingsPlansPurchaseRecommendationDetail> ? savingsPlansPurchaseRecommendationDetails, SavingsPlansPurchaseRecommendationSummary? savingsPlansPurchaseRecommendationSummary, SupportedSavingsPlansType? savingsPlansType, TermInYears? termInYears}) -
SavingsPlansPurchaseRecommendation.fromJson(Map<
String, dynamic> json) -
factory
Properties
- accountScope → AccountScope?
-
The account scope that you want your recommendations for. Amazon Web
Services calculates recommendations including the management account and
member accounts if the value is set to
PAYER. If the value isLINKED, recommendations are calculated for individual member accounts only.final - hashCode → int
-
The hash code for this object.
no setterinherited
- lookbackPeriodInDays → LookbackPeriodInDays?
-
The lookback period in days, used to generate the recommendation.
final
- paymentOption → PaymentOption?
-
The payment option used to generate the recommendation.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
savingsPlansPurchaseRecommendationDetails
→ List<
SavingsPlansPurchaseRecommendationDetail> ? -
Details for the Savings Plans we recommend that you purchase to cover
existing Savings Plans eligible workloads.
final
- savingsPlansPurchaseRecommendationSummary → SavingsPlansPurchaseRecommendationSummary?
-
Summary metrics for your Savings Plans Recommendations.
final
- savingsPlansType → SupportedSavingsPlansType?
-
The requested Savings Plans recommendation type.
final
- termInYears → TermInYears?
-
The Savings Plans recommendation term in years, used to generate the
recommendation.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited