ServiceSpecification class

Hardware specifications for the service that you want recommendations for.

Constructors

ServiceSpecification({EC2Specification? eC2Specification})
ServiceSpecification.fromJson(Map<String, dynamic> json)
factory

Properties

eC2Specification → EC2Specification?
The Amazon EC2 hardware specifications that you want AWS to provide recommendations for.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited