TargetInstance class

Details on recommended instance.

Constructors

TargetInstance({String? currencyCode, bool? defaultTargetInstance, String? estimatedMonthlyCost, String? estimatedMonthlySavings, ResourceUtilization? expectedResourceUtilization, ResourceDetails? resourceDetails})
TargetInstance.fromJson(Map<String, dynamic> json)
factory

Properties

currencyCode → String?
The currency code that AWS used to calculate the costs for this instance.
final
defaultTargetInstance → bool?
Indicates whether this recommendation is the defaulted AWS recommendation.
final
estimatedMonthlyCost → String?
Expected cost to operate this instance type on a monthly basis.
final
estimatedMonthlySavings → String?
Estimated savings resulting from modification, on a monthly basis.
final
expectedResourceUtilization → ResourceUtilization?
Expected utilization metrics for target instance type.
final
hashCode → int
The hash code for this object.
no setterinherited
resourceDetails → ResourceDetails?
Details on the target instance type.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited