TotalImpactFilter class

Filters cost anomalies based on the total impact.

Constructors

TotalImpactFilter({required NumericOperator numericOperator, required double startValue, double? endValue})

Properties

endValue → double?
The upper bound dollar value used in the filter.
final
hashCode → int
The hash code for this object.
no setterinherited
numericOperator → NumericOperator
The comparing value used in the filter.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startValue → double
The lower bound dollar value used in the filter.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited