UtilizationByTime class

The amount of utilization, in hours.

Constructors

UtilizationByTime({List<ReservationUtilizationGroup>? groups, DateInterval? timePeriod, ReservationAggregates? total})
UtilizationByTime.fromJson(Map<String, dynamic> json)
factory

Properties

groups → List<ReservationUtilizationGroup>?
The groups that this utilization result uses.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timePeriod → DateInterval?
The period of time that this utilization was used for.
final
total → ReservationAggregates?
The total number of reservation hours that were used.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited